.. QM sim documentation master file, created by
   sphinx-quickstart on Sun Apr 30 17:04:27 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Python library for simulation of quantum mechanical systems.
============================================================

Features 
--------

- 1D and 2D systems
- Choice of finite difference scheme
- Stationary and temporal solutions
- Plots
- CPU and GPU calculations

Planned features
----------------
- Boundary conditions
- 3D systems
- Transfer matrix for transmission ect.
- Testing

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   usage
   api
   examples
   contribution

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
